# Changes

All notable changes to this project will be documented in this file.

The format is based on [Keep a
Changelog](https://keepachangelog.com/en/1.0.0/), and this project
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [v0.1.0] - 2021-01-08

- First public preview release.

[unreleased]: https://github.com/guendto/jomiel-comm/compare/v0.1.0..HEAD
[v0.1.0]: https://github.com/guendto/jomiel-comm/releases/tag/v0.1.0
